@@ -12,7 +12,7 @@
 
 #ifndef HAVE_ASPRINTF
 extern int asprintf(char **ret, const char *format, ...);
-//extern int vasprintf(char **ret, const char *format, va_list args);
+/* extern int vasprintf(char **ret, const char *format, va_list args); */
 #endif /* HAVE_ASPRINTF */
 
 #include "GTG.h"
@@ -50,9 +50,9 @@ static gtg_flag_t paje_flags;
 
 
 /* in non-buffered mode, flush a file */
-#define FLUSH(file) \
-	if(paje_flags & GTG_FLAG_NOTBUF) \
-		fflush(file)
+#define FLUSH(file)                             \
+    if(paje_flags & GTG_FLAG_NOTBUF)            \
+        fflush(file)
 
 #define PRINT_PAJE_HEADER()                     \
     if ( !_is_paje_header_written ) {           \
@@ -82,33 +82,33 @@ static int compression_ratio = 0;
 /* compress data and write to disk */
 void paje_print(FILE* file, const char*format, ...)
 {
-  int len = 0;
-  int ret = 0;
-  va_list args;
-  char* tmp_buf = NULL;
-  va_start(args, format);
+    int len = 0;
+    int ret = 0;
+    va_list args;
+    char* tmp_buf = NULL;
+    va_start(args, format);
 
-  if(compression_ratio) {
-    len = vasprintf(&tmp_buf, format, args);
-    va_end(args);
+    if(compression_ratio) {
+        len = vasprintf(&tmp_buf, format, args);
+        va_end(args);
 
-    ret = gtg_compress_m2f(&z, tmp_buf, len, file);
-    if (ret < 0) {
-      fprintf(stderr, "gtg: an error occured while compressing\n");
+        ret = gtg_compress_m2f(&z, tmp_buf, len, file);
+        if (ret < 0) {
+            fprintf(stderr, "gtg: an error occured while compressing\n");
+        }
+    } else {
+        /* don't compress, write directly to disk */
+        vfprintf(file, format, args);
+        va_end(args);
     }
-  } else {
-    /* don't compress, write directly to disk */
-    vfprintf(file, format, args);
-    va_end(args);
-  }
 }
 
 trace_return_t pajeSetCompress(int val)
 {
-  compression_ratio = val;
-  if(val)
-    gtg_compress_init(&z, compression_ratio);
-  return TRACE_SUCCESS;
+    compression_ratio = val;
+    if(val)
+        gtg_compress_init(&z, compression_ratio);
+    return TRACE_SUCCESS;
 }
 
 #else  /* HAVE_LIBZ */
@@ -117,7 +117,7 @@ trace_return_t pajeSetCompress(int val)
 
 trace_return_t pajeSetCompress(int val)
 {
-  return TRACE_ERR_WRITE;
+    return TRACE_ERR_WRITE;
 }
 
 #endif
@@ -127,7 +127,7 @@ void insert (doubleLinkList_t** first, doubleLinkList_t* item){
     varPrec time;
     doubleLinkList_t* iter = *first;
     if (!first || !item){
-        fprintf (stderr, "Invalid insert parameter. Leaving \n");
+        fprintf (stderr, "Invalid insert parameter. Leaving\n");
         exit(-1);
     }
     time = item->current.time;
@@ -136,7 +136,7 @@ void insert (doubleLinkList_t** first, doubleLinkList_t* item){
         *first=item;
         item->prev = NULL;
         item->next = NULL;
-        /*  printf (stderr, "Nil list \n"); */
+        /*  printf (stderr, "Nil list\n"); */
         return;
     }
     /* If to insert in first pos */
@@ -172,7 +172,7 @@ void initMerge (char* file, int rk, doubleLinkList_t* li){
     sprintf (f, "%s_proc%d.ept", file, rk);
     li->current.file = fopen (f, "a+");
     if (!li->current.file){
-        fprintf (stderr, "Failed to open generated trace. Leaving \n");
+        fprintf (stderr, "Failed to open generated trace. Leaving\n");
         exit (-1);
     }
     rewind (li->current.file);
@@ -182,42 +182,43 @@ void initMerge (char* file, int rk, doubleLinkList_t* li){
 
 
 #ifndef HAVE_GETLINE
-int getline(char** buf, int* size, FILE* stream)
+ssize_t getline(char** buf, size_t* size, FILE* stream)
 {
-  int alloc_size = 1024;
+    char *ret;
+    int alloc_size = 1024;
+    int nb_char = 0;
 
-  if(!*buf) {
-    /* we need to allocate the buffer */
-    alloc_size = 1024;
-    *buf = malloc(sizeof(char) * alloc_size);
-  } else {
-    alloc_size = *size;
-  }
-  int nb_char = 0;
-  *buf[0]=0;
-
-  do {
-    if(nb_char + 512 >= alloc_size) {
-      /* the next fgets may overflow the buffer, so let's
-	 allocate more space */
-      alloc_size *= 2;
-      *buf = realloc(*buf, alloc_size);
-      *size = alloc_size;
+    if(!(*buf)) {
+        /* we need to allocate the buffer */
+        alloc_size = 1024;
+        *buf = malloc(sizeof(char) * alloc_size);
+    } else {
+        alloc_size = *size;
     }
+    *buf[0]=0;
 
-    /* read at most 512 bytes */
-    char * ret = fgets((*buf)+nb_char, 512, stream);
+    do {
+        if(nb_char + 512 >= alloc_size) {
+            /* the next fgets may overflow the buffer, so let's
+             allocate more space */
+            alloc_size *= 2;
+            *buf = realloc(*buf, alloc_size);
+            *size = alloc_size;
+        }
 
-    if(!ret){
-      /* error while reading or EOF */
-      *size = 1;
-      (*buf)[0] = EOF;
-      return -1;
-    }
-    nb_char = strlen(*buf);
-  } while((*buf)[nb_char -1] !='\n');
+        /* read at most 512 bytes */
+        ret = fgets((*buf)+nb_char, 512, stream);
 
-  return nb_char;
+        if(!ret){
+            /* error while reading or EOF */
+            *size = 1;
+            (*buf)[0] = EOF;
+            return -1;
+        }
+        nb_char = strlen(*buf);
+    } while((*buf)[nb_char -1] !='\n');
+
+    return nb_char;
 }
 #endif	/* HAVE_GETLINE */
 
@@ -236,14 +237,18 @@ void myGetLine (doubleLinkList_t* li){
     if ((li->current.size)>0)
         sscanf (li->current.value, "%d %lf", &toto, &(li->current.time));
     else
-        fprintf (stderr, "failed to read \n");
+        fprintf (stderr, "failed to read\n");
 }
+
 /* need to run 'rm -f' force because there is no file some time*/
 void clean_files (char* fileName, int nbFile){
     int ret;
     char cmd[BUFFSIZE];
     sprintf (cmd, "rm -f %s_root.ept %s_proc*.ept", filename,filename);
     ret = system(cmd);
+    if (ret == -1) {
+        perror("cleanfiles");
+    }
 }
 
 void merge (char* filename, int nbFile){
@@ -261,16 +266,16 @@ void merge (char* filename, int nbFile){
     /* Getting the first part of the trace (header+def) */
 #if HAVE_LIBZ
     if(compression_ratio)
-      sprintf (tmp, "%s.trace.z", filename);
+        sprintf (tmp, "%s.trace.z", filename);
     else
 #endif
-      sprintf (tmp, "%s.trace", filename);
+        sprintf (tmp, "%s.trace", filename);
 
     res = fopen (tmp, "w+");
     sprintf (tmp2, "%s_root.ept", filename);
     oldF = fopen (tmp2,"a+");
     if (res==NULL || oldF==NULL){
-        fprintf (stderr, "Failed to create the trace file. Leaving \n");
+        fprintf (stderr, "Failed to create the trace file. Leaving\n");
         exit (-1);
     }
     rewind (oldF);
@@ -291,9 +296,9 @@ void merge (char* filename, int nbFile){
         insert (&first, list+i);
     }
 
-    /*  fprintf (stderr, "Nb file = %d \n La liste : \n", nbFile); */
+    /*  fprintf (stderr, "Nb file = %d \n La liste :\n", nbFile); */
     /*  for (i=0;i<nbFile;i++)                                     */
-    /*      fprintf (stderr, "L1 = %s \n", list[i].current.value); */
+    /*      fprintf (stderr, "L1 = %s\n", list[i].current.value); */
 
     while (first && first->current.status != 0){
         paje_print (res, "%s", first->current.value);
@@ -312,14 +317,14 @@ void merge (char* filename, int nbFile){
                 insert (&first, iter);
         }
         /* for (i=0;i<nbFile;i++) */
-        /*     fprintf (stderr, "L1 = %s, st=%d \n", list[i].current.value,list[i].current.status); */
+        /*     fprintf (stderr, "L1 = %s, st=%d\n", list[i].current.value,list[i].current.status); */
         /* fprintf (stderr, "<---------------------------->\n\n"); */
     }
     fclose (res);
     clean_files (filename, nbFile);
 }
 
-const paje_color_t Paje_get_color(gtg_color_t p_color) {
+paje_color_t Paje_get_color(gtg_color_t p_color) {
     /** \todo it is not const*/
     int ret;
     paje_color_t res = NULL;
@@ -327,6 +332,7 @@ const paje_color_t Paje_get_color(gtg_color_t p_color) {
                    (float)GTG_COLOR_GET_RED(  p_color->rgb)/256,
                    (float)GTG_COLOR_GET_GREEN(p_color->rgb)/256,
                    (float)GTG_COLOR_GET_BLUE( p_color->rgb)/256);
+    (void)ret;
     return res;
 }
 
@@ -365,7 +371,7 @@ trace_return_t my_open (int rk){
 trace_return_t my_close (){
     trace_return_t ret = TRACE_ERR_CLOSE;
     if (procFile){
-	ret = (trace_return_t) fclose (procFile);
+        ret = (trace_return_t) fclose (procFile);
         procFile = NULL;
     }
     return ret;
@@ -383,18 +389,18 @@ trace_return_t pajeInitTrace   (const char* filenam, int rk, gtg_flag_t flags, i
 
     paje_flags = flags;
     if( rank==0 ||
-	! (flags & GTG_FLAG_USE_MPI)) {
+        ! (flags & GTG_FLAG_USE_MPI)) {
 
         sprintf (file, "%s_root.ept", filename);
         headFile = fopen (file, "w");
         if (!headFile){
-            fprintf (stderr, "Failed to open file %s. \n Leaving \n", file);
+            fprintf (stderr, "Failed to open file %s. \n Leaving\n", file);
             return ret;
         }
 
         pajeInitHeaderData( fmt );
 
-	FLUSH(headFile);
+        FLUSH(headFile);
     }
     return my_open(rank);
 }
@@ -406,274 +412,276 @@ trace_return_t pajeAddContType(const char* alias, const char* contType,
     if(verbose)
         printf("addCtType : name %s, alias %s, contType %s\n", name, alias, contType);
     if (headFile){
-      if(contType)
-        fprintf (headFile, "1 \"%s\" \"%s\" \"%s\" \n", alias, contType, name);
-      else
-        fprintf (headFile, "1 \"%s\" 0 \"%s\" \n", alias, name);
+        fprintf (headFile, "%d \"%s\" \"%s\" \"%s\"\n",
+                 paje_eventdefs[GTG_PAJE_EVTDEF_DefineContainerType].id, name, contType ? contType : "0", alias);
 
-	FLUSH(headFile);
+        FLUSH(headFile);
         return TRACE_SUCCESS;
     }
     return TRACE_ERR_WRITE;
 }
 
 trace_return_t pajeAddStateType   (const char* alias, const char* contType,
-                        const char* name){
+                                   const char* name){
     PRINT_PAJE_HEADER();
 
     if(verbose)
-	    printf("addStateType : alias %s, name %s, contType %s\n",  alias, name, contType);
+        printf("addStateType : alias %s, name %s, contType %s\n",  alias, name, contType);
     if (headFile){
-        fprintf (headFile, "3 \"%s\" \"%s\" \"%s\" \n", alias, contType, name);
+        fprintf (headFile, "%d \"%s\" \"%s\" \"%s\"\n",
+                 paje_eventdefs[GTG_PAJE_EVTDEF_DefineStateType].id, name, contType, alias);
 
-	FLUSH(headFile);
+        FLUSH(headFile);
         return TRACE_SUCCESS;
     }
     return TRACE_ERR_WRITE;
 }
 
 trace_return_t pajeAddEventType   (const char* alias, const char* contType,
-                        const char* name){
+                                   const char* name){
     PRINT_PAJE_HEADER();
 
     if(verbose)
-	    printf("addEventType :  alias %s, name %s, contType %s\n", alias, name, contType);
+        printf("addEventType :  alias %s, name %s, contType %s\n", alias, name, contType);
     if (headFile){
-        fprintf (headFile, "4 \"%s\" \"%s\" \"%s\" \n", alias, contType, name);
+        fprintf (headFile, "%d \"%s\" \"%s\" \"%s\"\n",
+                 paje_eventdefs[GTG_PAJE_EVTDEF_DefineEventType].id, name, contType, alias);
 
-	FLUSH(headFile);
+        FLUSH(headFile);
+        return TRACE_SUCCESS;
+    }
+    return TRACE_ERR_WRITE;
+}
+
+trace_return_t pajeAddVarType   (const char* alias   , const char* contType,
+                                 const char* name){
+    PRINT_PAJE_HEADER();
+
+    if(verbose)
+        printf("addVarType : alias %s, name %s, contType %s\n", alias, name, contType);
+    if (headFile){
+        fprintf (headFile, "%d \"%s\" \"%s\" \"0 0 0\" \"%s\"\n",
+                 paje_eventdefs[GTG_PAJE_EVTDEF_DefineVariableType].id, name, contType, alias);
+
+        FLUSH(headFile);
         return TRACE_SUCCESS;
     }
     return TRACE_ERR_WRITE;
 }
 
 trace_return_t pajeAddLinkType   (const char* alias   , const char* name,
-                       const char* contType, const char* srcContType,
-                       const char* destContType){
+                                  const char* contType, const char* srcContType,
+                                  const char* destContType){
     PRINT_PAJE_HEADER();
 
     if (verbose)
-        printf ("Add link type: alias: %s name: %s contType: %s src: %s des: %s \n", alias, name, contType, srcContType, destContType);
+        printf ("Add link type: alias: %s name: %s contType: %s src: %s des: %s\n", alias, name, contType, srcContType, destContType);
     if (headFile){
-        fprintf (headFile, "41 \"%s\" \"%s\" \"%s\" \"%s\" \"%s\" \n", alias, name, contType, srcContType, destContType);
+        fprintf (headFile, "%d \"%s\" \"%s\" \"%s\" \"%s\" \"%s\"\n",
+                 paje_eventdefs[GTG_PAJE_EVTDEF_DefineLinkType].id, name, contType, srcContType, destContType, alias);
 
-	FLUSH(headFile);
-        return TRACE_SUCCESS;
-    }
-    return TRACE_ERR_WRITE;
-}
-
-trace_return_t pajeAddVarType   (const char* alias   , const char* name,
-                      const char* contType){
-    PRINT_PAJE_HEADER();
-
-    if(verbose)
-	    printf("addVarType : alias %s, name %s, contType %s\n", alias, name, contType);
-    if (headFile){
-        fprintf (headFile, "50 \"%s\" \"%s\" \"%s\" \n", alias, contType, name);
-
-	FLUSH(headFile);
+        FLUSH(headFile);
         return TRACE_SUCCESS;
     }
     return TRACE_ERR_WRITE;
 }
 
 trace_return_t pajeAddEntityValue   (const char* alias, const char* entType,
-                          const char* name , const char* color){
+                                     const char* name , const char* color){
     PRINT_PAJE_HEADER();
 
     if(verbose)
         printf("addEntityValue : color %s, alias %s, name %s, type %s\n", color, alias, name, entType);
     if (headFile){
-        fprintf (headFile, "6 \"%s\" \"%s\" \"%s\" \"%s\"\n", alias, entType, name, color);
+        fprintf (headFile, "%d \"%s\" \"%s\" \"%s\" \"%s\"\n",
+                 paje_eventdefs[GTG_PAJE_EVTDEF_DefineEntityValue].id, entType, name, color, alias);
 
-	FLUSH(headFile);
+        FLUSH(headFile);
         return TRACE_SUCCESS;
     }
     return TRACE_ERR_WRITE;
 }
 
-trace_return_t pajeAddContainer   (varPrec time, const char* alias    ,
-                        const char*  type, const char* container,
-                        const char*  name, const char* file){
+trace_return_t pajeAddContainer(varPrec time, const char* alias,
+                                const char*  type, const char* container,
+                                const char*  name, const char* file){
     PRINT_PAJE_HEADER();
 
     if (headFile){
-      if(container && strcmp(container, "(null)")!=0 )
-        fprintf (headFile, "7 %.13e \"%s\" \"%s\" \"%s\" \"%s\" \"%s\"\n",
-                 time, alias, type, container, name, file);
-      else
-        fprintf (headFile, "7 %.13e \"%s\" \"%s\" 0 \"%s\" \"%s\"\n",
-                 time, alias, type, name, file);
+        if(container && strcmp(container, "(null)")!=0 )
+            fprintf (headFile, "%d %.13e \"%s\" \"%s\" \"%s\" \"%s\" \"%s\"\n",
+                     paje_eventdefs[GTG_PAJE_EVTDEF_CreateContainer].id, time, name, type, container, alias, file);
+        else
+            fprintf (headFile, "%d %.13e \"%s\" \"%s\" 0 \"%s\" \"%s\"\n",
+                     paje_eventdefs[GTG_PAJE_EVTDEF_CreateContainer].id, time, name, type, alias, file);
 
-
-	FLUSH(headFile);
+        FLUSH(headFile);
         return TRACE_SUCCESS;
     }
     return TRACE_ERR_WRITE;
 }
 
 trace_return_t pajeSeqAddContainer   (varPrec time, const char* alias    ,
-                           const char*  type, const char* container,
-                           const char*  name){
+                                      const char*  type, const char* container,
+                                      const char*  name){
     PRINT_PAJE_HEADER();
 
     if (headFile){
-      if(container && strcmp(container, "(null)")!=0)
-        fprintf (headFile, "7 %.13e \"%s\" \"%s\" \"%s\" \"%s\"\n",
-                 time, alias, type, container, name);
-      else
-        fprintf (headFile, "7 %.13e \"%s\" \"%s\" 0 \"%s\"\n",
-                 time, alias, type, name);
+        if(container && strcmp(container, "(null)")!=0 )
+            fprintf (headFile, "%d %.13e \"%s\" \"%s\" \"%s\" \"%s\"\n",
+                     paje_eventdefs[GTG_PAJE_EVTDEF_CreateContainer].id, time, name, type, container, alias);
+        else
+            fprintf (headFile, "%d %.13e \"%s\" \"%s\" 0 \"%s\"\n",
+                     paje_eventdefs[GTG_PAJE_EVTDEF_CreateContainer].id, time, name, type, alias);
 
-	FLUSH(headFile);
+        FLUSH(headFile);
         return TRACE_SUCCESS;
     }
     return TRACE_ERR_WRITE;
 }
 
 trace_return_t pajeDestroyContainer     (varPrec time, const char*  name,
-                              const char*  type){
+                                         const char*  type){
     PRINT_PAJE_HEADER();
 
     if (headFile){
-        fprintf (headFile, "8 %.13e \"%s\" \"%s\" \n",
-                 time, name, type);
+        fprintf (headFile, "%d %.13e \"%s\" \"%s\"\n",
+                 paje_eventdefs[GTG_PAJE_EVTDEF_DestroyContainer].id, time, name, type);
 
-	FLUSH(headFile);
+        FLUSH(headFile);
         return TRACE_SUCCESS;
     }
     return TRACE_ERR_WRITE;
 }
 
 trace_return_t pajeSetState   (varPrec time, const char* type,
-                    const char*  cont, const char* val){
+                               const char*  cont, const char* val){
     if(verbose)
         printf("SetState : type %s, container %s, val %s\n", type, cont, val);
     if (procFile){
-        fprintf (procFile, "10 %.13e \"%s\" \"%s\" \"%s\"\n",
-                 time, type, cont, val);
+        fprintf (procFile, "%d %.13e \"%s\" \"%s\" \"%s\"\n",
+                 paje_eventdefs[GTG_PAJE_EVTDEF_SetState].id, time, type, cont, val);
 
-	FLUSH(procFile);
+        FLUSH(procFile);
         return TRACE_SUCCESS;
     }
     return TRACE_ERR_WRITE;
 }
 
 trace_return_t pajePushState   (varPrec time, const char* type,
-                     const char*  cont, const char* val){
+                                const char*  cont, const char* val){
     if(verbose)
         printf("PushState : type %s, container %s, val %s\n", type, cont, val);
     if (procFile){
-        fprintf (procFile, "11 %.13e \"%s\" \"%s\" \"%s\"\n",
-                 time, type, cont, val);
+        fprintf (procFile, "%d %.13e \"%s\" \"%s\" \"%s\"\n",
+                 paje_eventdefs[GTG_PAJE_EVTDEF_PushState].id, time, type, cont, val);
 
-	FLUSH(procFile);
+        FLUSH(procFile);
         return TRACE_SUCCESS;
     }
     return TRACE_ERR_WRITE;
 }
 
 trace_return_t pajePopState   (varPrec time, const char* type,
-                    const char*  cont){
+                               const char*  cont){
     if(verbose)
         printf("PopState : type %s, container %s\n", type, cont);
     if (procFile){
-        fprintf (procFile, "12 %.13e \"%s\" \"%s\"\n",
-                 time, type, cont);
+        fprintf (procFile, "%d %.13e \"%s\" \"%s\"\n",
+                 paje_eventdefs[GTG_PAJE_EVTDEF_PopState].id, time, type, cont);
 
-	FLUSH(procFile);
+        FLUSH(procFile);
         return TRACE_SUCCESS;
     }
     return TRACE_ERR_WRITE;
 }
 
 trace_return_t pajeAddEvent   (varPrec time, const char* type,
-                    const char*  cont, const char* val){
+                               const char*  cont, const char* val){
     if(verbose)
         printf("AddEvent : type %s, cont %s, val %s\n", type, cont, val);
     if (procFile){
-        fprintf (procFile, "20 %.13e \"%s\" \"%s\" \"%s\"\n",
-                 time, type, cont, val);
+        fprintf (procFile, "%d %.13e \"%s\" \"%s\" \"%s\"\n",
+                 paje_eventdefs[GTG_PAJE_EVTDEF_NewEvent].id, time, type, cont, val);
 
-	FLUSH(procFile);
+        FLUSH(procFile);
         return TRACE_SUCCESS;
     }
     return TRACE_ERR_WRITE;
 }
 
 trace_return_t pajeStartLink   (varPrec time, const char* type,
-                     const char*   cont, const char* src,
-                     const char*   val , const char* key){
+                                const char*   cont, const char* src,
+                                const char*   val , const char* key){
     if (verbose)
         printf ("Start link: type: %s container: %s src: %s val: %s key %s\n",
-                 type, cont, src, val, key);
+                type, cont, src, val, key);
     if (procFile){
-        fprintf (procFile, "42 %.13e \"%s\" \"%s\" \"%s\" \"%s\" \"%s\"\n",
-                 time, type, cont, src, val, key);
+        fprintf (procFile, "%d %.13e \"%s\" \"%s\" \"%s\" \"%s\" \"%s\"\n",
+                 paje_eventdefs[GTG_PAJE_EVTDEF_StartLink].id, time, type, cont, src, val, key);
 
-	FLUSH(procFile);
+        FLUSH(procFile);
         return TRACE_SUCCESS;
     }
     return TRACE_ERR_WRITE;
 }
 
 trace_return_t pajeEndLink   (varPrec time, const char* type,
-                   const char*   cont, const char* dest,
-                   const char*   val , const char* key){
+                              const char*   cont, const char* dest,
+                              const char*   val , const char* key){
     if (verbose)
         printf ("End link type: %s container: %s src: %s val: %s key %s\n",
-                 type, cont, dest, val, key);
+                type, cont, dest, val, key);
     if (procFile){
-        fprintf (procFile, "43 %.13e \"%s\" \"%s\" \"%s\" \"%s\" \"%s\"\n",
-                 time, type, cont, dest, val, key);
+        fprintf (procFile, "%d %.13e \"%s\" \"%s\" \"%s\" \"%s\" \"%s\"\n",
+                 paje_eventdefs[GTG_PAJE_EVTDEF_EndLink].id, time, type, cont, dest, val, key);
 
-	FLUSH(procFile);
+        FLUSH(procFile);
         return TRACE_SUCCESS;
     }
     return TRACE_ERR_WRITE;
 }
 
 trace_return_t pajeSetVar   (varPrec time, const char*  type,
-                  const char*  cont, varPrec val){
+                             const char*  cont, varPrec val){
     if (verbose)
         printf ("SetVar: type: %s container: %s value: %e\n",
                 type, cont, val);
     if (procFile){
-        fprintf (procFile, "51 %.13e \"%s\" \"%s\" %e\n",
-                 time, type, cont, val);
+        fprintf (procFile, "%d %.13e \"%s\" \"%s\" %e\n",
+                 paje_eventdefs[GTG_PAJE_EVTDEF_SetVariable].id, time, type, cont, val);
 
-	FLUSH(procFile);
+        FLUSH(procFile);
         return TRACE_SUCCESS;
     }
     return TRACE_ERR_WRITE;
 }
 
 trace_return_t pajeAddVar   (varPrec time, const char*  type,
-                  const char*  cont, varPrec val){
+                             const char*  cont, varPrec val){
     if (verbose)
         printf ("AddVar: type: %s container: %s value: %e\n",
                 type, cont, val);
     if (procFile){
-        fprintf (procFile, "52 %.13e \"%s\" \"%s\" %e\n",
-                 time, type, cont, val);
+        fprintf (procFile, "%d %.13e \"%s\" \"%s\" %e\n",
+                 paje_eventdefs[GTG_PAJE_EVTDEF_AddVariable].id, time, type, cont, val);
 
-	FLUSH(procFile);
+        FLUSH(procFile);
         return TRACE_SUCCESS;
     }
     return TRACE_ERR_WRITE;
 }
 
 trace_return_t pajeSubVar   (varPrec time, const char*  type,
-                  const char*  cont, varPrec val){
+                             const char*  cont, varPrec val){
     if (verbose)
         printf ("SubVar: type: %s container: %s value: %e\n",
                 type, cont, val);
     if (procFile){
-        fprintf (procFile, "53 %.13e \"%s\" \"%s\" %e\n",
-                 time, type, cont, val);
+        fprintf (procFile, "%d %.13e \"%s\" \"%s\" %e\n",
+                 paje_eventdefs[GTG_PAJE_EVTDEF_SubVariable].id, time, type, cont, val);
 
-	FLUSH(procFile);
+        FLUSH(procFile);
         return TRACE_SUCCESS;
     }
     return TRACE_ERR_WRITE;
@@ -681,11 +689,11 @@ trace_return_t pajeSubVar   (varPrec time, const char*  type,
 
 trace_return_t pajeAddComment   (const char*  comment){
     if (verbose)
-        printf ("AddComment: %s \n",comment);
+        printf ("AddComment: %s\n",comment);
 
     if (procFile){
-	fprintf(procFile,"#%s\r\n",comment);
-	FLUSH(procFile);
+        fprintf(procFile,"#%s\r\n",comment);
+        FLUSH(procFile);
         return TRACE_SUCCESS;
     }
     return TRACE_ERR_WRITE;
@@ -701,11 +709,11 @@ trace_return_t pajeEndTrace (){
         MPI_Barrier (MPI_COMM_WORLD);
         MPI_Comm_size (MPI_COMM_WORLD, &size);
         if(verbose)
-            fprintf (stderr, "USING MPI \n");
+            fprintf (stderr, "USING MPI\n");
     }
     if (rank==0)
 #endif	/* USE_MPI */
-    merge (filename, size);
+        merge (filename, size);
 
     if (nameTmp)
         free (nameTmp);
@@ -732,8 +740,7 @@ trace_return_t viteEndTrace (){
  * Hack that will be removed
  */
 FILE *pajeGetProcFile() {
-  return procFile;
+    return procFile;
 }
 
 #endif
-
